import { Component, RefObject, ReactNode, ReactElement } from 'react';
import PropTypes from 'prop-types';
import { Animated, View, StyleProp, ViewStyle } from 'react-native';
import { Rect } from './Utility';
import { Insets, Placement, Mode } from './Types';
interface PopoverProps {
    isVisible?: boolean;
    placement?: Placement;
    animationConfig?: Partial<Animated.TimingAnimationConfig>;
    verticalOffset?: number;
    displayArea?: Rect;
    displayAreaInsets?: Insets;
    popoverStyle?: StyleProp<ViewStyle>;
    arrowStyle?: StyleProp<ViewStyle>;
    backgroundStyle?: StyleProp<ViewStyle>;
    arrowShift?: number;
    onOpenStart?: () => void;
    onOpenComplete?: () => void;
    onRequestClose?: () => void;
    onCloseStart?: () => void;
    onCloseComplete?: () => void;
    onPositionChange?: () => void;
    debug?: boolean;
}
interface PublicPopoverProps extends PopoverProps {
    mode?: Mode;
    from?: Rect | RefObject<View> | ((sourceRef: RefObject<View>, openPopover: () => void) => ReactNode) | ReactNode;
}
interface PublicPopoverState {
    isVisible: boolean;
}
export default class Popover extends Component<PublicPopoverProps, PublicPopoverState> {
    static propTypes: {
        isVisible: PropTypes.Requireable<boolean>;
        from: PropTypes.Requireable<string | number | boolean | {} | PropTypes.ReactElementLike | PropTypes.ReactNodeArray>;
        displayArea: PropTypes.Requireable<Required<PropTypes.InferProps<{
            x: PropTypes.Requireable<number>;
            y: PropTypes.Requireable<number>;
            width: PropTypes.Requireable<number>;
            height: PropTypes.Requireable<number>;
        }>>>;
        displayAreaInsets: PropTypes.Requireable<PropTypes.InferProps<{
            left: PropTypes.Requireable<number>;
            right: PropTypes.Requireable<number>;
            top: PropTypes.Requireable<number>;
            bottom: PropTypes.Requireable<number>;
        }>>;
        placement: PropTypes.Requireable<Placement>;
        animationConfig: PropTypes.Requireable<object>;
        verticalOffset: PropTypes.Requireable<number>;
        popoverStyle: any;
        arrowStyle: any;
        backgroundStyle: any;
        arrowShift: PropTypes.Requireable<number>;
        onOpenStart: PropTypes.Requireable<(...args: any[]) => any>;
        onOpenComplete: PropTypes.Requireable<(...args: any[]) => any>;
        onRequestClose: PropTypes.Requireable<(...args: any[]) => any>;
        onCloseStart: PropTypes.Requireable<(...args: any[]) => any>;
        onCloseComplete: PropTypes.Requireable<(...args: any[]) => any>;
        onPositionChange: PropTypes.Requireable<(...args: any[]) => any>;
        debug: PropTypes.Requireable<boolean>;
    };
    static defaultProps: Partial<PublicPopoverProps>;
    state: {
        isVisible: boolean;
    };
    private sourceRef;
    render(): ReactElement;
}
export {};
